@@ -1,24 +1,3 @@
-# ------------------------------------------------------------------------------------------------ #
-# MIT License                                                                                      #
-#                                                                                                  #
-# Copyright (c) 2020, Microsoft Corporation                                                        #
-#                                                                                                  #
-# Permission is hereby granted, free of charge, to any person obtaining a copy of this software    #
-# and associated documentation files (the "Software"), to deal in the Software without             #
-# restriction, including without limitation the rights to use, copy, modify, merge, publish,       #
-# distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the    #
-# Software is furnished to do so, subject to the following conditions:                             #
-#                                                                                                  #
-# The above copyright notice and this permission notice shall be included in all copies or         #
-# substantial portions of the Software.                                                            #
-#                                                                                                  #
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING    #
-# BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND       #
-# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,     #
-# DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,   #
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.          #
-# ------------------------------------------------------------------------------------------------ #
-
 r"""
 
 Utilities
@@ -73,11 +52,16 @@ Object Reference
     coax.utils.merge_dicts
     coax.utils.pretty_print
     coax.utils.pretty_repr
+    coax.utils.quantiles
+    coax.utils.quantiles_uniform
+    coax.utils.quantile_cos_embedding
     coax.utils.reload_recursive
     coax.utils.render_episode
     coax.utils.safe_sample
     coax.utils.single_to_batch
+    coax.utils.stack_trees
     coax.utils.tree_ravel
+    coax.utils.unvectorize
 
 
 """
@@ -104,7 +88,9 @@ from ._array import (
     merge_dicts,
     safe_sample,
     single_to_batch,
+    stack_trees,
     tree_ravel,
+    unvectorize,
 )
 from ._jit import jit
 from ._misc import (
@@ -129,6 +115,7 @@ from ._misc import (
     render_episode,
 )
 from ._segment_tree import SegmentTree, SumTree, MinTree, MaxTree
+from ._quantile_funcs import quantiles, quantiles_uniform, quantile_cos_embedding
 
 
 __all__ = (
@@ -173,9 +160,14 @@ __all__ = (
     'merge_dicts',
     'pretty_print',
     'pretty_repr',
+    'quantiles',
+    'quantiles_uniform',
+    'quantile_cos_embedding',
     'reload_recursive',
     'render_episode',
     'safe_sample',
     'single_to_batch',
+    'stack_trees',
     'tree_ravel',
+    'unvectorize',
 )
